Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: The IUT list is provided as a marketing service for vendors who have a viable contract with an accredited laboratory for the testing of a cryptographic module. The CMVP does not have detailed information about the specific cryptographic module or when the...
Date: 2016-10-11

# You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov

# Cryptographic Module Validation Program CMVP

### Implementation Under Test List

The IUT list is provided as a marketing service for vendors who have a viable contract with an accredited laboratory for the testing of a cryptographic module. The CMVP does not have detailed information about the specific cryptographic module or when the test report will be submitted to the CMVP for validation. When the lab submits the test report to the CMVP, the module will transition from the IUT list to the MIP list. If you would like more information about a specific cryptographic module or its schedule, please contact the vendor.

Last Updated: 10/23/2020

Module Name | Vendor Name | Standard | IUT Date
--- | --- | --- | ---
ADVA CRYPTOMUX (MA-2C2C3LT-A) and CRYPTOMUX+ (MA-B2C3LT-A) encryption modules | ADVA Optical Networking SE | FIPS 140-2 | 7/16/2020
AMD Cryptographic Coprocessor (CCP) Module | Advanced Micro Devices | FIPS 140-3 | 9/25/2020
APACER SSD Drive SV240 | Apacer Technology Inc. | FIPS 140-2 | 6/15/2020
Apple CoreCrypto Kernel Space Module for ARM | Apple Inc. | FIPS 140-3 | 9/21/2020
Apple CoreCrypto Kernel Space Module for Intel | Apple Inc. | FIPS 140-3 | 9/21/2020
Apple CoreCrypto User Space Module for ARM | Apple Inc. | FIPS 140-3 | 9/21/2020
Apple CoreCrypto User Space Module for Intel | Apple Inc. | FIPS 140-3 | 9/21/2020
Apple Secure Key Store Cryptographic Module, 11.0 | Apple Inc. | FIPS 140-3 | 9/21/2020
Aruba 7280 Mobility Controller with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | 11/27/2019
Aruba AP-318, AP-374, AP-375, AP-377 and AP-387 Series Wireless Access Points with ArubaOS FIPS Firmware | Aruba, a Hewlett Packard Enterprise company | FIPS 140-2 | 11/27/2019
Sansec HSM | Beijing Sansec Technology Development Co., Ltd | FIPS 140-2 | 3/22/2020
PTP 820C, PTP 820C-HP, PTP 820C 2E2SX, PTP 820S, PTP 820N, PTP 820A, PTP 820G, PTP 820GX, PTP 850E | Cambium Networks, Ltd. | FIPS 140-2 | 5/15/2020
FibeAir® IP-20C, FibeAir® IP-20C-HP, FibeAir® IP-20C 2E2SX, FibeAir® IP-20S, FibeAir® IP-20N, FibeAir® IP-20A, FibeAir® IP-20G, FibeAir® IP-20GX, FibeAir® IP-50E | Ceragon Networks, Ltd. | FIPS 140-2 | 5/15/2020
Check Point Cryptographic Library | Check Point Software Technologies | FIPS 140-2 | 4/2/2020
Cisco Aironet 1562e/i/d/ps, 2802e/i, 3802e/i/p, 4800 & IW6300H-AC/DC/DCW LAN Access points | Cisco Systems, Inc | FIPS 140-2 | 8/6/2020
Cisco 8000 Series Routers | Cisco Systems, Inc. | FIPS 140-2 | 2/9/2020
Cisco Aironet 9115AXI/AXE, 9120AXI/AXE/AXP, 9130 AXI/AXE and 9105 AXI/AXE Wireless LAN Access Points | Cisco Systems, Inc. | FIPS 140-2 | 8/10/2020
Cisco ASR 9000 Aggregated Services Routers | Cisco Systems, Inc. | FIPS 140-2 | 8/17/2020
Cisco Catalyst Embedded Wireless Controller on Access Point IOS XE 16.12 | Cisco Systems, Inc. | FIPS 140-2 | 1/23/2020
CliniComp Data Acquisition Cryptographic Module | CliniComp, Intl. | FIPS 140-2 | 3/18/2020
CloudGenix Inc. Controller | CloudGenix Inc. | FIPS 140-2 | 9/26/2019
CloudGenix Inc. Instant-On Networks (ION) devices ION 2000, ION 3000, and ION 7000 | CloudGenix Inc. | FIPS 140-2 | 9/26/2019
Ruckus ICX 7150, 7250, 7750 Series Switch/Router | CommScope Technologies LLC | FIPS 140-2 | 8/20/2020
Ruckus ICX 7450 Series Switch/Router | CommScope Technologies LLC | FIPS 140-2 | 8/20/2020
Ruckus ICX 7550 Series Switch/Router | CommScope Technologies LLC | FIPS 140-2 | 8/13/2020
Ruckus ICX 7650 Series Switch/Router | CommScope Technologies LLC | FIPS 140-2 | 8/20/2020
Ruckus ICX 7850 Series Switch/Router | CommScope Technologies LLC | FIPS 140-2 | 8/13/2020
Ruckus Networks SmartZone 144 (SZ144) and SmartZone 300 (SZ300) WLAN Controllers | CommScope Technologies LLC | FIPS 140-2 | 8/9/2020
Ruckus Networks Virtual SmartZone - Data Plane (vSZ-D) | CommScope Technologies LLC | FIPS 140-2 | 8/17/2020
Ruckus Networks Virtual SmartZone (vSZ) WLAN Controller | CommScope Technologies LLC | FIPS 140-2 | 8/17/2020
Ruckus R610 Access Point, R720 Access Point, T610s Access Point, T710s Access Point, R650 Access Point, R750 Access Point and T750se Access Point | CommScope Technologies LLC | FIPS 140-2 | 8/6/2020
Comtech Systems Corporation CS67PLUS Cryptographic Module (CCM) | Comtech Systems, Inc. | FIPS 140-2 | 7/30/2020
Crypto4A QASM | Crypto4A Technologies Inc. | FIPS 140-2 | 7/10/2019
Vocality RoIP and DTECH M3/M3X Multi-Function Gateway Appliances | Cubic Corporation | FIPS 140-2 | 12/2/2019
CyberCogs HSM | CyberCogs Inc. | FIPS 140-2 | 9/30/2020
CYB06445LQI-S3D42 and CYS0644ABZI-S2D44 | Cypress Semiconductor | FIPS 140-2 | 2/3/2020
BSAFE Crypto-C Micro Edition | Dell EMC | FIPS 140-2 | 7/27/2020
DINAMO CD, XP, and ST Hardware Security Modules | DINAMO Networks, Inc. | FIPS 140-2 | 12/18/2019
DINAMO Pocket Hardware Security Module | DINAMO Networks, Inc. | FIPS 140-2 | 12/18/2019
Distech Java Cryptographic Module | Distech Controls Inc. | FIPS 140-2 | 4/3/2020
Distech SSL Cryptographic Module | Distech Controls Inc. | FIPS 140-2 | 4/3/2020
DocuSign QSCD Appliance | DocuSign, Inc. | FIPS 140-2 | 9/4/2020
MS1200 | eWBM | FIPS 140-2 | 5/30/2019
Cryptographic Module for BIG-IP (R) | F5 Networks | FIPS 140-2 | 4/24/2020
F5(R) vCMP Cryptographic Module | F5 Networks | FIPS 140-2 | 4/24/2020
F5(R) Device Cryptographic Module | F5 Networks, Inc | FIPS 140-2 | 4/24/2020
Annapurna NVMe SSD | FADU, Inc. | FIPS 140-2 | 5/3/2019
FortiAnalyzer 6.2 | Fortinet, Inc. | FIPS 140-2 | 8/17/2020
FortiClient 6.4 for Windows | Fortinet, Inc. | FIPS 140-2 | 9/10/2020
FortiGate-600D/1200D/1500D/3000D/3700D and FortiGate-5001D with FortiGate-5144C Chassis | Fortinet, Inc. | FIPS 140-2 | 9/25/2019
FortiManager 6.2 | Fortinet, Inc. | FIPS 140-2 | 8/17/2020
FortiSandbox-1000F/2000E/3000E | Fortinet, Inc. | FIPS 140-2 | 7/6/2020
SafeNet Luna Backup HSM Cryptographic Module | Gemalto, a Thales Company | FIPS 140-2 | 1/29/2020
HUB Multipurpose HSM Architecture | HUB Security | FIPS 140-2 | 11/15/2019
Hughes HT2010 Satellite Terminal | Hughes Network Systems, LLC | FIPS 140-2 | 8/17/2020
Hughes HT2300, HT2500, HT2550, HT2650 Satellite Terminals | Hughes Network Systems, LLC | FIPS 140-2 | 8/17/2020
Hughes IP Gateway | Hughes Network Systems, LLC | FIPS 140-2 | 8/17/2020
Hypersecu ServSec HSM Cryptographic Module | Hypersecu Information Systems Inc | FIPS 140-2 | 6/11/2019
HyTrust CloudControl (TM) Cryptographic Module | HyTrust, Inc. | FIPS 140-2 | 9/10/2019
HyTrust KeyControl Cryptographic Module | HyTrust, Inc. | FIPS 140-2 | 9/10/2019
IBM TS1160 Tape Drive | IBM Corporation | FIPS 140-2 | 8/6/2019
IBM(R) Security QRadar(R) Cryptographic Security Kernel | IBM Corporation | FIPS 140-2 | 5/7/2018
Infoblox Trinzic DDI Appliances TE-805, TE-825, TR-805, ND-805, TE-1415, TE-1425, TR-1405, ND-1405, TE-2215, TE-2225, TR-2205, ND-2205, TE-4015, TE-4025, TR-4005, NE-4005 | Infoblox | FIPS 140-2 | 10/13/2020
Infoblox Trinzic Virtual DDI appliance | Infoblox | FIPS 140-2 | 10/13/2020
Intel(R) Converged Security Engine for Tiger Lake, Rocket Lake, and Elkhart Lake | Intel Corporation | FIPS 140-2 | 5/27/2020
Intel(R) CSE hybrid module for Tiger Lake, Rocket Lake, and Elkhart Lake | Intel Corporation | FIPS 140-2 | 5/27/2020
Intel® Optane™ SSD DC D5800X | Intel Corporation | FIPS 140-3 | 9/26/2020
IQVIA Java Crypto Module | IQVIA | FIPS 140-2 | 4/14/2020
Juniper Networks ACX5448-M Routers | Juniper Networks | FIPS 140-2 | 8/31/2020
Juniper Networks EX4650, QFX5120, QFX5200 and QFX5210 Ethernet Switches | Juniper Networks | FIPS 140-2 | 9/25/2020
Juniper Networks NFX350 Network Services Platform | Juniper Networks, Inc. | FIPS 140-2 | 10/10/2020
LogRhythm 7.4.8 AI Engine | LogRhythm | FIPS 140-2 | 10/21/2020
LogRhythm 7.4.8 Client Console | LogRhythm | FIPS 140-2 | 10/21/2020
LogRhythm 7.4.8 Data Processor | LogRhythm | FIPS 140-2 | 10/21/2020
LogRhythm 7.4.8 Platform Manager | LogRhythm | FIPS 140-2 | 10/21/2020
LogRhythm 7.4.8 System Monitor Agent | LogRhythm | FIPS 140-2 | 10/21/2020
LogRhythm 7.6 Data Indexer (Linux) | LogRhythm | FIPS 140-2 | 10/21/2020
McAfee Core Crypto OpenSSL Module (user) | McAfee LLC | FIPS 140-2 | 8/4/2019
McAfee Core Cryptographic Module (kernel) | McAfee LLC | FIPS 140-2 | 8/4/2019
McAfee Core Cryptographic Module (user) | McAfee LLC | FIPS 140-2 | 8/4/2019
Network Security Platform Sensor NS7500 | McAfee, LLC | FIPS 140-2 | 8/23/2020
Microchip Trust Anchor TA100 | Microchip Technology Inc | FIPS 140-2 | 4/29/2020
NV-2108 Flashtec PCIe NVRAM Drive | Microchip Technology, Inc. | FIPS 140-2 | 7/23/2020
Code Integrity in Windows 10 and Windows Server version 2004 | Microsoft Corporation | FIPS 140-2 | 6/1/2020
Cryptographic Primitives Library in Windows 10 and Windows Server version 2004 | Microsoft Corporation | FIPS 140-2 | 6/1/2020
Kernel Mode Cryptographic Primitives Library in Windows 10 and Windows Server version 2004 | Microsoft Corporation | FIPS 140-2 | 6/1/2020
Secure Kernel Code Integrity in Windows 10 and Windows Server version 2004 | Microsoft Corporation | FIPS 140-2 | 6/1/2020
Command Encryption Module | Mitsubishi Space Software Co., Ltd. | FIPS 140-2 | 2/10/2020
Monaco Communication Cryptographic Module 1.0 | Monaco Enterprises Inc. | FIPS 140-2 | 10/15/2020
NetApp CryptoMod | NetApp, Inc. | FIPS 140-2 | 5/15/2020
7705 SAR-OS SAR-A/M Cryptographic Module (SARCM) | Nokia Corporation | FIPS 140-2 | 8/13/2020
SR-OS Cryptographic Module | Nokia Corporation | FIPS 140-2 | 8/13/2020
Nuvoton Cryptographic Library 2.0 | Nuvoton Technology Corporation | FIPS 140-3 | 10/1/2020
OpenSSL FIPS Provider 3.0 | OpenSSL Software Services Inc. | FIPS 140-2 | 10/20/2020
Oracle Linux 7 GnuTLS Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 libgcrypt Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 Libreswan Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 NSS Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 OpenSSH Client Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 OpenSSH Server Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 OpenSSL Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 7 Unbreakable Enterprise Kernel (UEK5) Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 8 GnuTLS Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 8 libgcrypt Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 8 NSS Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 8 OpenSSL Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Linux 8 Unbreakable Enterprise Kernel (UEK6) Cryptographic Module | Oracle Corporation | FIPS 140-2 | 9/24/2020
Oracle Solaris Kernel Cryptographic Framework (kCF) | Oracle Corporation | FIPS 140-2 | 7/10/2019
Oracle Solaris Userland Cryptographic Framework (uCF) | Oracle Corporation | FIPS 140-2 | 7/10/2019
osn_cryptolib | OSNexus Corporation | FIPS 140-2 | 9/10/2019
Capri 1.0 | Pensando Systems, Inc | FIPS 140-2 | 10/18/2019
Pensando TLS Library | Pensando Systems, Inc | FIPS 140-2 | 10/23/2020
Purity Encryption Module | Pure Storage, Inc. | FIPS 140-2 | 8/19/2020
Qumulo Secure | Qumulo, Inc. | FIPS 140-2 | 8/28/2020
CryptoManager Root of Trust (CMRT) | Rambus Inc. | FIPS 140-2 | 5/12/2020
Riverbed Cryptographic module (VN) for Branch | Riverbed Technology, Inc. | FIPS 140-2 | 9/27/2020
Riverbed Cryptographic module (VN) for Controller | Riverbed Technology, Inc. | FIPS 140-2 | 9/27/2020
SAAB Encrypted Automatic Identification System Cryptographic Module (EAISCM) | Saab AB (publ) TransponderTech (SAAB) | FIPS 140-2 | 10/16/2020
CN Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 | 5/4/2020
CN6000 Series Encryptors | Senetas Corporation Ltd., distributed by Thales SA (SafeNet) | FIPS 140-2 | 5/4/2020
Taglio PIV Applet on NXP JCOP 3 SecID P60 CS (OSB) | Taglio | FIPS 140-2 | 4/6/2020
Trulink Control Logic Module CL6792-M1 | Telephonics Corporation | FIPS 140-2 | 1/2/2020
Trulink Control Logic Module CL6882-M1 | Telephonics Corporation | FIPS 140-2 | 1/2/2020
Tera2 PCoIP Zero Client Processors | Teradici Corporation | FIPS 140-2 | 1/28/2020
Thales ProtectServer PCIe HSM 3 | Thales | FIPS 140-2 | 6/23/2020
TW-900/950 TSM Shadow and TW-870/875 TSM Ghost | TrellisWare Technologies, Inc. | FIPS 140-2 | 8/8/2019
Trend Micro Endpoint Encryption Cryptographic Module | Trend Micro, Inc. | FIPS 140-2 | 6/4/2020
AN/GRC-262 | Ultra Electronics TCS Inc. | FIPS 140-2 | 7/8/2019
Uplogix Model 500, 5000, LM80, LM83X | Uplogix, Inc. | FIPS 140-2 | 5/18/2020
RAD X-1040 AES-256 | Vcinity, Inc. | FIPS 140-2 | 7/30/2020
Versa Networks Branch | Versa Networks, Inc. | FIPS 140-2 | 6/8/2020
Versa Networks Controller | Versa Networks, Inc. | FIPS 140-2 | 6/8/2020
VirtruCrypto - FIPS JavaScript Module | Virtru Corporation | FIPS 140-2 | 6/11/2020
Vocera Cryptographic Module | Vocera Communications, Inc. | FIPS 140-2 | 6/18/2020
WatchKey ProX USB Token Cryptographic Module | WatchData Technologies Pte Ltd | FIPS 140-2 | 7/28/2020
Ultrastar® DC HC550 - Western Digital® | Western Digital Corporation | FIPS 140-2 | 6/12/2020
Ultrastar® DC SN840 - Western Digital® | Western Digital Corporation | FIPS 140-2 | 6/12/2020
Ultrastar® He¹² and Ultrastar® DC HC 520 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | 9/2/2020
Ultrastar® He¹º and Ultrastar® DC HC510 TCG Enterprise HDD | Western Digital Corporation | FIPS 140-2 | 9/2/2020
XCrypt Full Disk | Zettaset, Inc. | FIPS 140-2 | 8/13/2020
Displayed: 140
Not Displayed: 1
Total: 141

#### Contacts

Beverly Trapnell - NIST CMVP Program Manager
cmvp@nist.gov

Carolyn French - CCCS CMVP Program Manager
CMVP@cyber.gc.ca

#### Group

Security Testing, Validation and Measurement

#### Topics

Security and Privacy: cryptography, testing & validation

Technologies: hardware, software & firmware

#### Related Projects

Deep learning neural networks for CMVP report validation
Automated Cryptographic Validation Testing
Cryptographic Algorithm Validation Program
FIPS 140-3 Transition Effort
Random Bit Generation
Threshold Cryptography
Testing Laboratories

#### Group

Security Testing, Validation and Measurement

#### Topics

Security and Privacy: cryptography, testing & validation

Technologies: hardware, software & firmware

#### Related Projects

Deep learning neural networks for CMVP report validation
Automated Cryptographic Validation Testing
Cryptographic Algorithm Validation Program
FIPS 140-3 Transition Effort
Random Bit Generation
Threshold Cryptography
Testing Laboratories

Created October 11, 2016, Updated October 16, 2020